@@ -1,3 +1,16 @@
+//! the git mit-relates to binary
+
+#![warn(
+    rust_2018_idioms,
+    unused,
+    rust_2021_compatibility,
+    nonstandard_style,
+    future_incompatible,
+    missing_copy_implementations,
+    missing_debug_implementations,
+    missing_docs
+)]
+
 #[cfg(test)]
 extern crate quickcheck;
 #[cfg(test)]
